/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec;


/**
 * Internal class of Wyjec implementation, containing methods, flags, etc. used for debugging.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class Debugging {

    /**
     * A flag that enables debugging of Wyjec. It should be set to <code>false</code> during
     * normal operation.
     */
    public static final boolean DEBUG_ENABLED = false;

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private Debugging() { }

    /**
     * If debugging is enabled, checks value of given condition and throws
     * <code>DebugException</code> if it's not equal to <code>true</code>. If debugging is
     * disabled (<code>DEBUG_ENABLED</code> flag is set to <code>false</code>) it does nothing.
     *
     * @param condition value of condition to check
     * @param errorMessage message to use when throwing an exception
     */
    public static void assume(boolean condition, String errorMessage) {
        if (DEBUG_ENABLED) {
            if (!condition) {
                throw new DebugException(errorMessage);
            }
        }
    }

    /**
     * If debugging is enabled, throws <code>DebugException</code> every time it's called. If
     * debugging is disabled (<code>DEBUG_ENABLED</code> flag is set to <code>false</code>) it
     * does nothing.
     */
    public static void assumeNotReached() {
        if (DEBUG_ENABLED) {
            throw new DebugException("This code should not be reached");
        }
    }


    /**
     * Exception thrown in case one of assertions located in Wyjec core fails.
     *
     * @author Zbigniew Chyla (zbigniew@chyla.pl)
     */
    static final class DebugException extends RuntimeException {

        /**
         * Constructs new <code>DebugException</code> instance with given informal message
         * attached.
         *
         * @param msg message informing about detected problem
         */
        private DebugException(String msg) {
            super(msg);
        }

    }

}
