/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.core.optparameters;

import pl.chyla.wyjec.core.OptParameters;
import pl.chyla.wyjec.core.Type;


/**
 * Represents function's declared list of optional parameters of type integer. Instance of this
 * class may be used as part of function's signature.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class IntegerOptParameters extends OptParameters {

    /**
     * Constructs object representing function's declared optional parameters of type
     * {@link Type#INTEGER}.
     * <p>
     * Note: Before the object representing parameters can be used, it must be bound to
     * function's signature.
     */
    public IntegerOptParameters() {
        super();
    }

    /**
     * Returns type of optional parameters represented by the object; returned value is always
     * <code>Type.INTEGER</code>.
     *
     * @return type of parameters represented by the object
     * @see OptParameters#getType()
     */
    public Type getType() {
        return Type.INTEGER;
    }

}
