/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdconsts;

import pl.chyla.wyjec.core.IConstantsParser;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Constants parser that doesn't recognize any strings as constants. This class should be used
 * in case no constants are desirable but instance of constants parser is needed.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class EmptyConstantsParser implements IConstantsParser {

    /**
     * Instance of <code>EmptyConstantsParser</code>, accessible from outside via
     * {@link #getInstance()}.
     */
    private static final EmptyConstantsParser instance = new EmptyConstantsParser();

    /**
     * Private (empty) constructor to disallow instantiating of the class from outside. Class'
     * instance should be accessed via {@link #getInstance()} getter.
     */
    private EmptyConstantsParser() { }

    /**
     * Returns instance of <code>EmptyConstantsParser</code> which can be safely used independly
     * from other threads which also get <code>EmptyConstantsParser</code> using this method.
     * It's undefined whether this method returns newly created instance or not.
     *
     * @return instance of <code>EmptyConstantsParser</code>
     */
    public static EmptyConstantsParser getInstance() {
        return instance;
    }

    /**
     * Empty implementation of constant parsing, returns immediately without giving any value.
     *
     * @param result {@link Value} for storing recognized value, not used
     * @param constStr string representation of constant to parse, not used
     * @return <code>false</code>
     */
    public boolean parseConstant(Value result, ReadableRawString constStr) {
        return false;
    }

}
