/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.utils.ArrayUtils;


/**
 * Class grouping functions from other sources that provide arrays of functions.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class MergedFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private MergedFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances with elements copied
     * from arrays contained in <code>funcsArrays</code> parameter.
     *
     * @param funcsArrays array of arrays of functions
     * @return new array containing all functions from components of <code>funcsArrays</code>
     */
    public static Function[] getFunctions(Function[][] funcsArrays) {
        return (Function[]) ArrayUtils.flattenArrays(funcsArrays, new Function[0]);
    }

}
