/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.stdfuncs.booleanfuncs.BooleanFunctions;
import pl.chyla.wyjec.stdfuncs.datefuncs.DateFunctions;
import pl.chyla.wyjec.stdfuncs.floatfuncs.FloatFunctions;
import pl.chyla.wyjec.stdfuncs.integerfuncs.IntegerFunctions;
import pl.chyla.wyjec.stdfuncs.stringfuncs.StringFunctions;


/**
 * Class grouping standard functions of Wyjec (Wyjec standard library).
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class StandardFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private StandardFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances representing Wyjec
     * standard functions.
     *
     * @return new array containing all functions from Wyjec standard library
     */
    public static Function[] getFunctions() {
        return MergedFunctions.getFunctions(
            new Function[][] {
                IntegerFunctions.getFunctions(),
                BooleanFunctions.getFunctions(),
                StringFunctions.getFunctions(),
                FloatFunctions.getFunctions(),
                DateFunctions.getFunctions()});
    }

}
