/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.booleanfuncs;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.parameters.BooleanParameter;


/**
 * Returns negation of a parameter, i.e. boolean false if the parameter is true and boolean
 * false otherwise (logical negation).
 *
 * @wyjec.func not
 * @wyjec.example "{not|{false}}" "true" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnNot extends BooleanFunction {

    /**
     * Value to negate
     * @wyjec.param value
     */
    private static final BooleanParameter pValue = new BooleanParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "not";
    }

    protected boolean execute() {
        return !getParameter(pValue);
    }

}
