/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.booleanfuncs;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.optparameters.BooleanOptParameters;
import pl.chyla.wyjec.core.parameters.BooleanParameter;


/**
 * Returns boolean true if any parameter has value true and boolean false otherwise (logical
 * alternative).
 *
 * @wyjec.func or
 * @wyjec.example "{or|{false}|{true}|{false}}" "true" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnOr extends BooleanFunction {

    /**
     * First value to use (its value will be copied to result in case its the only
     * parameter)
     * @wyjec.param value
     */
    private static final BooleanParameter pValue = new BooleanParameter();

    /**
     * Other optional values to use
     * @wyjec.param optValues
     */
    private static final BooleanOptParameters pOptValues = new BooleanOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, pOptValues);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "or";
    }

    protected boolean execute() {
        if (getParameter(pValue)) {
            return true;
        }
        int optParamsCount = getOptParametersCount(pOptValues);
        boolean result = false;
        for (int i = 0; i < optParamsCount; i++) {
            if (getParameter(pOptValues, i)) {
                result = true;
                break;
            }
        }
        return result;
    }

}
