/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic;

import java.util.Calendar;
import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.DateFunction;
import pl.chyla.wyjec.core.parameters.DateParameter;
import pl.chyla.wyjec.core.parameters.IntegerParameter;
import pl.chyla.wyjec.utils.SimpleCalendar;


/**
 * Returns date value calculated by adding specified number of minutes to given base date.
 *
 * @wyjec.func +minutes
 * @wyjec.example "{+minutes|{&#64;1978-09-11}|{63}}" "1978-09-11 01:03:00" date
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnAdditionMinutes extends DateFunction {

    /**
     * Base date to use for calculation
     * @wyjec.param baseDate
     */
    private static final DateParameter pBaseDate = new DateParameter();

    /**
     * Number of minutes to add to base date
     * @wyjec.param shiftMinutes
     */
    private static final IntegerParameter pShiftMinutes = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pBaseDate, pShiftMinutes}, null);

    /**
     * Temporary calendar instance used for calculation
     */
    private SimpleCalendar tmpCal = new SimpleCalendar();

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "+minutes";
    }

    protected long execute() {
        tmpCal.setTimeInMillis(getParameter(pBaseDate));
        tmpCal.add(Calendar.MINUTE, (int) getParameter(pShiftMinutes));
        return tmpCal.getTimeInMillis();
    }

}
