/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.basic;

import java.util.Calendar;
import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.DateFunction;
import pl.chyla.wyjec.core.parameters.DateParameter;
import pl.chyla.wyjec.utils.SimpleCalendar;


/**
 * Returns date value formed by setting time of the day in given base date to 00:00:00
 * (midnight).
 *
 * @wyjec.func midnight
 * @wyjec.example "{midnight|{&#64;2005-01-01 02:24:01}}" "2005-01-01 00:00:00" date
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnMidnight extends DateFunction {

    /**
     * Base date to use for calculation
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, null);

    /**
     * Temporary calendar instance used for calculation
     */
    private SimpleCalendar tmpCal = new SimpleCalendar();

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "midnight";
    }

    protected long execute() {
        tmpCal.setTimeInMillis(getParameter(pDate));
        tmpCal.set(Calendar.MILLISECOND, 0);
        tmpCal.set(Calendar.SECOND, 0);
        tmpCal.set(Calendar.MINUTE, 0);
        tmpCal.set(Calendar.HOUR_OF_DAY, 0);
        return tmpCal.getTimeInMillis();
    }

}
