/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.DateFunction;
import pl.chyla.wyjec.core.optparameters.DateOptParameters;
import pl.chyla.wyjec.core.parameters.DateParameter;


/**
 * Returns one of given date parameters such that no other parameter is less than it.
 * "less" means here that date represented by a value is before the other one.
 *
 * @wyjec.func min
 * @wyjec.example "{min|{&#64;1978-09-11}|{&#64;1977-03-09}|{&#64;1975-04-09}}"
 * "1975-04-09 00:00:00" date
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnMin extends DateFunction {

    /**
     * First date used in comparision
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    /**
     * Other optional dates used in comparision
     * @wyjec.param optDates
     */
    private static final DateOptParameters pOptDates = new DateOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, pOptDates);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "min";
    }

    protected long execute() {
        long minDate = getParameter(pDate);
        int optParamsCount = getOptParametersCount(pOptDates);
        for (int i = 0; i < optParamsCount; i++) {
            long date = getParameter(pOptDates, i);
            if (date < minDate) {
                minDate = date;
            }
        }
        return minDate;
    }

}
