/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnAbs;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnAddition;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnCeil;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnDivision;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnFloor;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnModulo;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnMultiplication;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnNegation;
import pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic.FnSubtraction;
import pl.chyla.wyjec.stdfuncs.floatfuncs.basic.FnFloat;
import pl.chyla.wyjec.stdfuncs.floatfuncs.basic.FnStr;
import pl.chyla.wyjec.stdfuncs.floatfuncs.relations.FnEqual;
import pl.chyla.wyjec.stdfuncs.floatfuncs.relations.FnGreater;
import pl.chyla.wyjec.stdfuncs.floatfuncs.relations.FnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.floatfuncs.relations.FnLess;
import pl.chyla.wyjec.stdfuncs.floatfuncs.relations.FnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.floatfuncs.selection.FnIf;
import pl.chyla.wyjec.stdfuncs.floatfuncs.selection.FnMax;
import pl.chyla.wyjec.stdfuncs.floatfuncs.selection.FnMin;
import pl.chyla.wyjec.stdfuncs.floatfuncs.selection.FnSelect;


/**
 * Factory for all standard functions operating on values of Wyjec's float type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FloatFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private FloatFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances representing all standard
     * float functions.
     *
     * @return new array of instances of standard float functions
     */
    public static Function[] getFunctions() {
        return new Function[] {
            new FnAddition(), new FnSubtraction(), new FnNegation(), new FnAbs(),
            new FnMultiplication(), new FnDivision(), new FnModulo(),
            new FnCeil(), new FnFloor(),
            new FnEqual(), new FnGreaterOrEqual(), new FnGreater(), new FnLessOrEqual(),
            new FnLess(),
            new FnMin(), new FnMax(), new FnIf(), new FnSelect(),
            new FnFloat(), new FnStr()};
    }

}
