/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.relations;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.optparameters.IntegerOptParameters;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns boolean true if all numbers given as parameters have the same value and boolean
 * false otherwise.
 *
 * @wyjec.func =
 * @wyjec.example "{=|{3}|{+|{2}|{1}}|{3}}" "true" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnEqual extends BooleanFunction {

    /**
     * First number used in comparision
     * @wyjec.param value
     */
    private static final IntegerParameter pValue = new IntegerParameter();

    /**
     * Other optional numbers to compare to the first one
     * @wyjec.param optValues
     */
    private static final IntegerOptParameters pOptValues = new IntegerOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, pOptValues);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "=";
    }

    protected boolean execute() {
        long firstValue = getParameter(pValue);
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            if (getParameter(pOptValues, i) != firstValue) {
                return false;
            }
        }
        return true;
    }

}
