/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.BooleanParameter;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;


/**
 * Returns one of two given string parameters, depending on value of condition given as
 * boolean parameter. If the condition is true, the function returns the first string,
 * otherwise it returns the second one.
 *
 * @wyjec.func if
 * @wyjec.example "{if|{>|3|1}|ok|impossible}" "ok" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnIf extends StringFunction {

    /**
     * Value that determines which string should be returned.
     * @wyjec.param condition
     */
    private static final BooleanParameter pCondition = new BooleanParameter();

    /**
     * First string parameter, returned as function's result if condition is true.
     * @wyjec.param value1
     */
    private static final StringParameter pValue1 = new StringParameter();

    /**
     * Second string parameter, returned as function's result if condition is false.
     * @wyjec.param value2
     */
    private static final StringParameter pValue2 = new StringParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pCondition, pValue1, pValue2}, null, true);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "if";
    }

    protected void execute(RawString result) {
        if (getParameter(pCondition)) {
            result.append(getParameter(pValue1));
        } else {
            result.append(getParameter(pValue2));
        }
    }

}
