/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.optparameters.StringOptParameters;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Returns one of given parameters such that no other parameter is greater (strings are
 * compared lexicographically).
 *
 * @wyjec.func max
 * @wyjec.example "{max|Jan|Adam|Kowalski|Adam|Janek}" "Kowalski" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnMax extends StringFunction {

    /**
     * First value used in comparision
     * @wyjec.param value
     */
    private static final StringParameter pValue = new StringParameter();

    /**
     * Other optional values used in comparision
     * @wyjec.param optValues
     */
    private static final StringOptParameters pOptValues = new StringOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, pOptValues);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "max";
    }

    protected void execute(RawString result) {
        ReadableRawString maxValue = getParameter(pValue);
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            ReadableRawString value = getParameter(pOptValues, i);
            if (value.compareTo(maxValue) > 0) {
                maxValue = value;
            }
        }
        result.append(maxValue);
    }

}
